[CCCL] 瘦身 + 补全: 移除 cudax/python/libcudacxx-tests 冗余文件, 新增 c2h 测试助手 + cmake 构建系统 + 8 个 CUDA thrust examples
变更摘要:
- 删除: cudax/ (783 files, 7.2M) — 实验性组件,竞赛不需要
- 删除: python/ (226 files, 2.0M) — Python 绑定,竞赛不需要
- 删除: libcudacxx/{test,benchmarks,codegen,cmake,share} (4432 files, 31M)
保留: libcudacxx/include/ (1463 headers, cuda::std 编译依赖)
- 新增: c2h/ (27 files) — CUB Catch2 测试辅助头文件,编译 243 个测试必需
- 新增: cmake/ (29 files) — CCCL 原生 CMake 构建系统
- 新增: thrust/examples/cuda/ (7 files) + cpp_integration/ (1 file)
async_reduce, custom_temporary_allocation, explicit_cuda_stream,
global_device_vector, range_view, unwrap_pointer, wrap_pointer, device
结果: cccl_upstream 从 74M→35M (瘦身 53%), 核心内容 100% 保留:
27/27 tuning headers, 78 benchmarks, 243 tests,
60 thrust examples, 18 CUB examples, 全部编译头文件
This commit is contained in:
@@ -1,82 +0,0 @@
|
||||
//===----------------------------------------------------------------------===//
|
||||
//
|
||||
// Part of CUDA Experimental in CUDA C++ Core Libraries,
|
||||
// under the Apache License v2.0 with LLVM Exceptions.
|
||||
// See https://llvm.org/LICENSE.txt for license information.
|
||||
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
|
||||
// SPDX-FileCopyrightText: Copyright (c) 2024 NVIDIA CORPORATION & AFFILIATES.
|
||||
//
|
||||
//===----------------------------------------------------------------------===//
|
||||
|
||||
#include <cuda/experimental/execution.cuh>
|
||||
|
||||
#include <nv/target>
|
||||
|
||||
#include <cstdio>
|
||||
|
||||
#include <cuda_runtime_api.h>
|
||||
|
||||
namespace cudax = cuda::experimental;
|
||||
namespace ex = cudax::execution;
|
||||
|
||||
// This example demonstrates how to use the experimental CUDA implementation of
|
||||
// C++26's std::execution async tasking framework.
|
||||
|
||||
int main()
|
||||
{
|
||||
try
|
||||
{
|
||||
auto tctx = ex::thread_context{};
|
||||
auto sctx = ex::stream_context{cuda::device_ref{0}};
|
||||
auto gpu = sctx.get_scheduler();
|
||||
|
||||
const auto bulk_shape = 10;
|
||||
const auto bulk_fn = [] __device__(const int index, int i) noexcept {
|
||||
const int tid = static_cast<int>(blockIdx.x * blockDim.x + threadIdx.x);
|
||||
if (tid < bulk_shape)
|
||||
{
|
||||
printf("Hello from bulk task on device! index = %d, i = %d\n", index, i);
|
||||
}
|
||||
};
|
||||
|
||||
auto start =
|
||||
// begin work on the GPU:
|
||||
ex::schedule(gpu)
|
||||
|
||||
// execute a device lambda on the GPU:
|
||||
| ex::then([] __device__() noexcept -> int {
|
||||
printf("Hello from lambda on device!\n");
|
||||
return 42;
|
||||
})
|
||||
|
||||
// do some parallel work on the GPU:
|
||||
| ex::bulk(ex::par, bulk_shape, bulk_fn) //
|
||||
|
||||
// transfer execution back to the CPU:
|
||||
| ex::continues_on(tctx.get_scheduler())
|
||||
|
||||
// execute a host/device lambda on the CPU:
|
||||
| ex::then([] __host__ __device__(int i) noexcept -> int {
|
||||
NV_IF_ELSE_TARGET(NV_IS_HOST,
|
||||
(printf("Hello from lambda on host! i = %d\n", i);),
|
||||
(printf("OOPS! still on the device! i = %d\n", i);))
|
||||
return i + 1;
|
||||
});
|
||||
|
||||
// run the task, wait for it to finish, and get the result
|
||||
auto [i] = ex::sync_wait(std::move(start)).value();
|
||||
printf("All done on the host! result = %d\n", i);
|
||||
}
|
||||
catch (cuda::cuda_error const& e)
|
||||
{
|
||||
std::printf("CUDA error: %s\n", e.what());
|
||||
}
|
||||
catch (std::exception const& e)
|
||||
{
|
||||
std::printf("Exception: %s\n", e.what());
|
||||
}
|
||||
catch (...)
|
||||
{
|
||||
std::printf("Unknown exception\n");
|
||||
}
|
||||
}
|
||||
Reference in New Issue
Block a user